module.exports = (api) => {
  const lintSetting = {
    'editor.codeActionsOnSave': {
      'source.fixAll': true,
      'source.fixAll.eslint': true,
      'source.fixAll.stylelint': true,
    },
    'eslint.alwaysShowStatus': true,
    'eslint.options': {
      extensions: [
        '.ts',
        '.tsx',
        '.js',
        '.jsx',
        '.vue',
      ],
    },
    'eslint.validate': [
      'javascript',
      'html',
      'vue',
      'vue-html',
      'html',
    ],
    'stylelint.snippet': [
      'css',
      'less',
      'postcss',
      'vue',
      'scss',
      'sass',
    ],
    'stylelint.validate': [
      'css',
      'less',
      'postcss',
      'vue',
      'scss',
      'sass',
    ],
    'stylelint.packageManager': 'npm',
    '[javascript]': {
      'editor.defaultFormatter': 'dbaeumer.vscode-eslint',
    },
    '[typescript]': {
      'editor.defaultFormatter': 'dbaeumer.vscode-eslint',
    },
  };

  const lintExtension = {
    recommendations: [
      'johnsoncodehk.volar',
      'dbaeumer.vscode-eslint',
      'stylelint.vscode-stylelint',
    ],
  };

  const settingPos = '.vscode/settings.json';
  const extensionPos = '.vscode/extensions.json';

  api.render((files) => {
    const fileList = files;
    const settingContent = (files[settingPos] || '{}')
      .replace(/\/\/.*/g, '')
      .replace(/\n/g, '');

    const settings = JSON.parse(settingContent);

    Object.assign(settings, lintSetting);

    fileList[settingPos] = JSON.stringify(settings, null, 2);

    const extensions = (fileList[extensionPos] || '{}')
      .replace(/\/\/.*/g, '')
      .replace(/\n/g, '');

    const extensionContent = JSON.parse(extensions);

    if (!extensionContent.recommendations) {
      extensionContent.recommendations = [];
    }

    extensionContent.recommendations = extensionContent.recommendations.concat(
      lintExtension.recommendations,
    );

    extensionContent.recommendations = [...new Set(extensionContent.recommendations)];

    fileList[extensionPos] = JSON.stringify(extensionContent, null, 2);
  });
};
